@@ -239,7 +239,7 @@ object_storage::set_multi_key_obj(const torrent::raw_string& key, const std::str
     if (r_itr == m_rlookup.end())
       r_itr = m_rlookup.insert(std::make_pair(cmd_key, rlookup_type::mapped_type())).first;
 
-    if (std::find_if(r_itr->second.begin(), r_itr->second.end(), [key](value_type* type) { return key == type->first; }) == r_itr->second.end())
+    if (std::none_of(r_itr->second.begin(), r_itr->second.end(), [key](auto type) { return key == type->first; }))
       r_itr->second.push_back(&*itr);
   }
 
@@ -253,8 +253,8 @@ object_storage::rlookup_list(const std::string& cmd_key) {
   rlookup_iterator r_itr = m_rlookup.find(cmd_key);
 
   if (r_itr != m_rlookup.end())
-    std::transform(r_itr->second.begin(), r_itr->second.end(), std::back_inserter(result),
-                   std::bind(&key_type::c_str, std::bind(std::mem_fn(&value_type::first), std::placeholders::_1)));
+    for (auto pair : r_itr->second)
+      result.push_back(pair->first.c_str());
 
   return result;
 }
@@ -266,8 +266,8 @@ object_storage::rlookup_clear(const std::string& cmd_key) {
   if (r_itr == m_rlookup.end())
     return;
 
-  for (rlookup_mapped_iterator first = r_itr->second.begin(), last = r_itr->second.end(); first != last; first++)
-    (*first)->second.object.erase_key(cmd_key);
+  for (auto& first : r_itr->second)
+    first->second.object.erase_key(cmd_key);
 
   r_itr->second.clear();
 }
